summaryrefslogtreecommitdiff
path: root/modules
diff options
context:
space:
mode:
authorCraig Jennings <c@cjennings.net>2026-05-10 15:25:27 -0500
committerCraig Jennings <c@cjennings.net>2026-05-10 15:25:27 -0500
commit0f9e308745b77ca589e5b25f415121058b9f08ee (patch)
tree3080ab24298b6b40b0542acce185312b906c2177 /modules
parenta0e5edfb3d77f34d0f71bdc9bb8bc3a563ee6436 (diff)
downloaddotemacs-0f9e308745b77ca589e5b25f415121058b9f08ee.tar.gz
dotemacs-0f9e308745b77ca589e5b25f415121058b9f08ee.zip
refactor(cj-org-text): rename to cj-org-text-lib for naming consistency
Same naming-convention fix as the cj-cache rename. Org-safe text sanitizers extracted in Phase 3 went into modules/cj-org-text.el, should have followed the established `-lib' suffix convention. Rename modules/cj-org-text.el -> modules/cj-org-text-lib.el; update provide form, file header, and the two (require 'cj-org-text) call sites in calendar-sync and test-cj-org-text-sanitize. No behavior change.
Diffstat (limited to 'modules')
-rw-r--r--modules/calendar-sync.el2
-rw-r--r--modules/cj-org-text-lib.el (renamed from modules/cj-org-text.el)6
2 files changed, 4 insertions, 4 deletions
diff --git a/modules/calendar-sync.el b/modules/calendar-sync.el
index 890dd9df..74b2e5c6 100644
--- a/modules/calendar-sync.el
+++ b/modules/calendar-sync.el
@@ -71,7 +71,7 @@
(require 'cl-lib)
(require 'subr-x)
-(require 'cj-org-text)
+(require 'cj-org-text-lib)
(defun calendar-sync--log-silently (format-string &rest args)
"Log FORMAT-STRING with ARGS without requiring the full config."
diff --git a/modules/cj-org-text.el b/modules/cj-org-text-lib.el
index 69224573..45b9ec2e 100644
--- a/modules/cj-org-text.el
+++ b/modules/cj-org-text-lib.el
@@ -1,4 +1,4 @@
;;; cj-org-text.el --- Pure helpers for sanitizing external text into Org -*- lexical-binding: t; -*-
;; Author: Craig Jennings <c@cjennings.net>
@@ -54,5 +54,5 @@ nil for nil input."
(cj/org-sanitize-property-value
(cj/org-sanitize-body-text text)))
-(provide 'cj-org-text)
-;;; cj-org-text.el ends here
+(provide 'cj-org-text-lib)
+;;; cj-org-text-lib.el ends here
@@ -1,4 +1,4 @@
-;;; cj-org-text.el --- Pure helpers for sanitizing external text into Org -*- lexical-binding: t; -*-
+;;; cj-org-text-lib.el --- Pure helpers for sanitizing external text into Org -*- lexical-binding: t; -*-
;; Author: Craig Jennings <c@cjennings.net>